@@ -8,6 +8,7 @@
  *
  * Copyright (c) 2020 Red Hat, Inc.
  ****************************************************************************** */
+// Copyright Contributors to the Open Cluster Management project
 /* eslint-disable no-underscore-dangle */
 /* eslint-disable max-len */
 import _ from 'lodash';
@@ -22,7 +23,7 @@ import { isRequired } from '../lib/utils';
 import pollRbacCache, { getUserRbacFilter } from '../lib/rbacCaching';
 
 export function getPropertiesWithList() {
-  return ['label', 'role', 'port', 'container'];
+  return ['label', 'role', 'port', 'container', 'category', 'rules', 'addon'];
 }
 
 // Is there a more efficient way?
@@ -175,7 +176,12 @@ function getRedisClient() {
       const redisInfo = redisUrl.split(':');
       const redisHost = redisInfo[0];
       const redisPort = redisInfo[1];
-      const redisCert = fs.readFileSync(process.env.redisCert || './rediscert/redis.crt', 'utf8');
+      let redisCert = '';
+      try {
+        redisCert = fs.readFileSync(process.env.redisCert || './rediscert/redis.crt', 'utf8');
+      } catch (e) {
+        logger.warn('Using insecure redis connection. Cert not mounted at ./rediscert/redis.crt', e.Message);
+      }
       const ipFamily = await getIPvFamily(redisHost);
       redisClient = redis.createClient(
         redisPort,
@@ -207,11 +213,11 @@ function getRedisClient() {
     });
 
     // Log redis connection events.
-    redisClient.on('error', (error) => {
-      logger.info('Error with Redis connection: ', error);
+    redisClient.on('error', () => {
+      logger.info('Error with Redis connection.');
     });
-    redisClient.on('end', (msg) => {
-      logger.info('The Redis connection has ended.', msg);
+    redisClient.on('end', () => {
+      logger.info('The Redis connection has ended.');
     });
   });
 }
@@ -226,6 +232,7 @@ if (process.env.NODE_ENV !== 'test') {
 
 // Applications queries are only interested in resources on the local cluster, in the appropriate API group
 const APPLICATION_MATCH = "(app:Application {cluster: 'local-cluster', apigroup: 'app.k8s.io'})";
+const ARGO_APPLICATION_MATCH = "(app:Application {apigroup: 'argoproj.io'})";
 const SUBSCRIPTION_MATCH = "(sub:Subscription {cluster: 'local-cluster', apigroup: 'apps.open-cluster-management.io'})";
 const PLACEMENTRULE_MATCH = "(pr:PlacementRule {cluster: 'local-cluster', apigroup: 'apps.open-cluster-management.io'})";
 const CHANNEL_MATCH = "(ch:Channel {cluster: 'local-cluster', apigroup: 'apps.open-cluster-management.io'})";
@@ -298,11 +305,35 @@ export default class RedisGraphConnector {
   async runApplicationsQuery() {
     const { withClause, whereClause } = await this.createWhereClause([], ['app']);
     const matchClause = `MATCH ${APPLICATION_MATCH} ${whereClause}`;
-    const returnClause = 'RETURN DISTINCT app._uid, app.name, app.namespace, app.created, app.dashboard, app.selfLink, app.label ORDER BY app.name, app.namespace ASC';
+    const returnClause = 'RETURN DISTINCT app._uid, app.name, app.namespace, app.created, app.apigroup, app.apiversion, app.dashboard, app.label, app.cluster ORDER BY app.name, app.namespace ASC';
     const query = `${withClause} ${matchClause} ${returnClause}`;
     return this.executeQuery({ query, removePrefix: false, queryName: 'runApplicationsQuery' });
   }
 
+  /*
+   * Get Argo Applications.
+   */
+  async runArgoApplicationsQuery() {
+    const { withClause, whereClause } = await this.createWhereClause([], ['app']);
+    const matchClause = `MATCH ${ARGO_APPLICATION_MATCH} ${whereClause}`;
+    const returnClause1 = 'RETURN DISTINCT app._uid, app.name, app.namespace, app.cluster, app.created, app.apigroup, app.apiversion, app.label,';
+    const returnClause2 = 'app.applicationSet, app.destinationName, app.destinationServer, app.destinationNamespace, app.repoURL, app.path, app.chart, app.targetRevision';
+    const orderBy = 'ORDER BY app.name, app.namespace, app.cluster ASC';
+    const query = `${withClause} ${matchClause} ${returnClause1} ${returnClause2} ${orderBy}`;
+    return this.executeQuery({ query, removePrefix: false, queryName: 'runArgoApplicationsQuery' });
+  }
+
+  /*
+   * Get Argo cluster secrets.
+   */
+  async runArgoClusterSecretsQuery() {
+    const { withClause, whereClause } = await this.createWhereClause([], ['s']);
+    const matchClause = `MATCH (s:Secret) ${whereClause} AND 'argocd.argoproj.io/secret-type=cluster' IN s.label`;
+    const returnClause = 'RETURN DISTINCT s._uid, s.label, s.cluster';
+    const query = `${withClause} ${matchClause} ${returnClause}`;
+    return this.executeQuery({ query, removePrefix: false, queryName: 'runArgoClusterSecretsQuery' });
+  }
+
   /*
    * Get a list of applications that have related clusters.
    * NOTE: If an app doesn't have resources in any cluster it won't be in the result.
@@ -352,7 +383,7 @@ export default class RedisGraphConnector {
   async runSubscriptionsQuery() {
     const { withClause, whereClause } = await this.createWhereClause([], ['sub']);
     const matchClause = `MATCH ${SUBSCRIPTION_MATCH} ${whereClause}`;
-    const returnClause = 'RETURN DISTINCT sub._uid, sub.name, sub.namespace, sub.created, sub.selfLink, sub.status, sub.channel, sub.timeWindow, sub.localPlacement';
+    const returnClause = 'RETURN DISTINCT sub._uid, sub.name, sub.namespace, sub.created, sub.status, sub.channel, sub.timeWindow, sub.localPlacement';
     const orderClause = 'ORDER BY sub.name, sub.namespace ASC';
     const query = `${withClause} ${matchClause} ${returnClause} ${orderClause}`;
     return this.executeQuery({ query, removePrefix: false, queryName: 'runSubscriptionsQuery' });
@@ -403,7 +434,7 @@ export default class RedisGraphConnector {
   async runPlacementRulesQuery() {
     const { withClause, whereClause } = await this.createWhereClause([], ['pr']);
     const matchClause = `MATCH ${PLACEMENTRULE_MATCH} ${whereClause}`;
-    const returnClause = 'RETURN DISTINCT pr._uid, pr.name, pr.namespace, pr.created, pr.selfLink, pr.replicas';
+    const returnClause = 'RETURN DISTINCT pr._uid, pr.name, pr.namespace, pr.created, pr.replicas';
     const orderClause = 'ORDER BY pr.name, pr.namespace ASC';
     const query = `${withClause} ${matchClause} ${returnClause} ${orderClause}`;
     return this.executeQuery({ query, removePrefix: false, queryName: 'runPlacementRulesQuery' });
@@ -439,7 +470,7 @@ export default class RedisGraphConnector {
   async runChannelsQuery() {
     const { withClause, whereClause } = await this.createWhereClause([], ['ch']);
     const matchClause = `MATCH ${CHANNEL_MATCH} ${whereClause}`;
-    const returnClause = 'RETURN DISTINCT ch._uid, ch.name, ch.namespace, ch.created, ch.selfLink, ch.type, ch.pathname';
+    const returnClause = 'RETURN DISTINCT ch._uid, ch.name, ch.namespace, ch.created, ch.type, ch.pathname';
     const orderClause = 'ORDER BY ch.name, ch.namespace ASC';
     const query = `${withClause} ${matchClause} ${returnClause} ${orderClause}`;
     return this.executeQuery({ query, removePrefix: false, queryName: 'runChannelsQuery' });
@@ -597,7 +628,7 @@ export default class RedisGraphConnector {
 
   // WORKAROUND: This function divides the query to prevent hitting the maximum query size. The tradeoff is
   // a slower execution time. Long term we need to replace with a more efficient query or rethink how we enforce
-  // rbac. Technical debt being tracked with: https://github.com/stolostron/backlog/issues/6016
+  // rbac. Technical debt being tracked with: https://github.com/open-cluster-management/backlog/issues/6016
   async getRelationshipsWithSeparatedQueryWorkaround(withClause, returnClause) {
     const startTime = Date.now();
     let relatedQueries = [];
@@ -632,7 +663,7 @@ export default class RedisGraphConnector {
       } else {
         returnClause = `${whereClause} AND (r._uid <> n._uid) RETURN DISTINCT ${countOnly ? 'r._uid, r.kind' : 'r'}`;
       }
-      // This is tech debt, tracking with: https://github.com/stolostron/backlog/issues/6016
+      // This is tech debt, tracking with: https://github.com/open-cluster-management/backlog/issues/6016
       if (withClause.length > MAX_LENGTH_WITH_CLAUSE) {
         return this.getRelationshipsWithSeparatedQueryWorkaround(withClause, returnClause);
       }
