@@ -6,17 +6,19 @@
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  ****************************************************************************** */
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import { AuthenticationError, GenericError, NetworkError } from './errors';
 
 describe('Errors', () => {
-  test('Test Authentication Error', async () => {
+  test('Authentication Error', async () => {
     expect(AuthenticationError).toMatchSnapshot();
   });
-  test('Test Generic Error', async () => {
+  test('Generic Error', async () => {
     expect(GenericError).toMatchSnapshot();
   });
-  test('Test Network Error', async () => {
+  test('Network Error', async () => {
     expect(NetworkError).toMatchSnapshot();
   });
 });
