@@ -6,8 +6,10 @@
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  ****************************************************************************** */
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-import { mockServer } from '@graphql-tools/mock';
+import { mockServer } from 'graphql-tools';
 import { typeDefs } from './index';
 
 describe('Schema', () => {
